==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebCalendarBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebCalendarBaseDescription = /*@__PURE__*/ (() => {
    class WebCalendarBaseDescription extends Description {
        constructor() {
            super();
            this.m = null;
            this.j = false;
            this.n = null;
            this.l = null;
            this.f = null;
            this.g = null;
        }
        get_type() {
            return "WebCalendarBase";
        }
        get type() {
            return this.get_type();
        }
        get selection() {
            return this.m;
        }
        set selection(a) {
            this.m = a;
            this.e("Selection");
        }
        get showWeekNumbers() {
            return this.j;
        }
        set showWeekNumbers(a) {
            this.j = a;
            this.e("ShowWeekNumbers");
        }
        get weekStart() {
            return this.n;
        }
        set weekStart(a) {
            this.n = a;
            this.e("WeekStart");
        }
        get locale() {
            return this.l;
        }
        set locale(a) {
            this.l = a;
            this.e("Locale");
        }
        get disabledDates() {
            return this.f;
        }
        set disabledDates(a) {
            this.f = a;
            this.e("DisabledDates");
        }
        get specialDates() {
            return this.g;
        }
        set specialDates(a) {
            this.g = a;
            this.e("SpecialDates");
        }
    }
    WebCalendarBaseDescription.$t = /*@__PURE__*/ markType(WebCalendarBaseDescription, 'WebCalendarBaseDescription', Description.$);
    return WebCalendarBaseDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebCalendarBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebCalendarBaseDescription = /*@__PURE__*/ (() => {
    class WebCalendarBaseDescription extends Description {
        get_type() {
            return "WebCalendarBase";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.o = null;
            this.l = false;
            this.p = null;
            this.n = null;
            this.i = null;
            this.h = null;
        }
        get selection() {
            return this.o;
        }
        set selection(a) {
            this.o = a;
            this.g("Selection");
        }
        get showWeekNumbers() {
            return this.l;
        }
        set showWeekNumbers(a) {
            this.l = a;
            this.g("ShowWeekNumbers");
        }
        get weekStart() {
            return this.p;
        }
        set weekStart(a) {
            this.p = a;
            this.g("WeekStart");
        }
        get locale() {
            return this.n;
        }
        set locale(a) {
            this.n = a;
            this.g("Locale");
        }
        get specialDates() {
            return this.i;
        }
        set specialDates(a) {
            this.i = a;
            this.g("SpecialDates");
        }
        get disabledDates() {
            return this.h;
        }
        set disabledDates(a) {
            this.h = a;
            this.g("DisabledDates");
        }
    }
    WebCalendarBaseDescription.$t = /*@__PURE__*/ markType(WebCalendarBaseDescription, 'WebCalendarBaseDescription', Description.$);
    return WebCalendarBaseDescription;
})();
